==> metaljs-0.0.1.tgz: package/karma.conf.js <==
module.exports = function(config) {
  config.set({
    browsers: ['Chrome'],

    frameworks: ['jspm', 'mocha', 'chai', 'sinon'],

    jspm: {
      // ES6 files need to go through jspm for module loading.
      loadFiles: ['test/**/*.js'],
      serveFiles: ['src/**/*.js']
    },

    files: [
      'node_modules/closure-templates/soyutils.js',
      'test/html/fixture/*.html'
    ],

    preprocessors: {
      // All src files should be included in the coverage report, except
      // Promise, since that's not our code for now. These files don't
      // need to go through the `babel` preprocessor, as the `coverage`
      // preprocessor already does the necessary conversion.
      'src/*.js': ['coverage'],
      'src/!(promise)/**/*.js': ['coverage'],

      // Since tests and Promise are not going through the `coverage`
      // preprocessor we need to explicitly make them go through `babel`.
      'src/promise/Promise.js': ['babel'],
      'test/**/*.js': ['babel'],

      // Fixture htmls should go through `html2js` so tests can access
      // them through the `window.__html__` variable.
      'test/html/fixture/*.html': ['html2js']
    },

    reporters: ['coverage', 'progress'],

    logLevel: config.LOG_ERROR,

    coverageReporter: {
      instrumenters: { isparta : require('isparta') },
      instrumenter: {
        '**/*.js': 'isparta'
      },
      reporters: [
        {
          type : 'text-summary'
        },
        {
          type : 'html'
        },
        {
          type: 'lcov',
          subdir: 'lcov'
        },
      ]
    }
  });
};

==> metaljs-0.0.2.tgz: package/karma.conf.js <==
module.exports = function(config) {
  config.set({
    browsers: ['Chrome'],

    frameworks: ['jspm', 'mocha', 'chai', 'sinon'],

    jspm: {
      // ES6 files need to go through jspm for module loading.
      loadFiles: ['test/src/**/*.js'],
      serveFiles: ['src/**/*.js']
    },

    files: [
      'node_modules/closure-templates/soyutils.js',
      'test/src/html/fixture/*.html'
    ],

    preprocessors: {
      // All src files should be included in the coverage report, except
      // async, since that's not our code for now. These files don't
      // need to go through the `babel` preprocessor, as the `coverage`
      // preprocessor already does the necessary conversion.
      'src/*.js': ['coverage'],
      'src/!(async)/**/*.js': ['coverage'],

      // Since tests and async are not going through the `coverage`
      // preprocessor we need to explicitly make them go through `babel`.
      'src/async/async.js': ['babel'],
      'test/src/**/*.js': ['babel'],

      // Fixture htmls should go through `html2js` so tests can access
      // them through the `window.__html__` variable.
      'test/src/html/fixture/*.html': ['html2js']
    },

    reporters: ['coverage', 'progress'],

    logLevel: config.LOG_ERROR,

    coverageReporter: {
      instrumenters: { isparta : require('isparta') },
      instrumenter: {
        '**/*.js': 'isparta'
      },
      reporters: [
        {
          type : 'text-summary'
        },
        {
          type : 'html'
        },
        {
          type: 'lcov',
          subdir: 'lcov'
        },
      ]
    }
  });
};
